@@ -2,15 +2,18 @@
 # encoding: utf-8
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
-__version__ = (0, 0, 8)
+__version__ = (0, 0, 9)
 __all__ = ["ApplicationWithMethods", "make_application"]
 
 from asyncio import gather
 from collections.abc import AsyncIterator, Callable, Iterable, Iterator, Sequence
+from ipaddress import ip_address
 from functools import cached_property, partial
 from itertools import chain
+from socket import socket, AF_INET, SOCK_DGRAM
 from sys import _getframe, maxsize
 from typing import overload, Literal, SupportsIndex, TypeVar
+from urllib.parse import urlsplit, urlunsplit
 
 from blacksheep import Application, Request, Router, WebSocket
 from blacksheep.contents import StreamedContent
@@ -36,6 +39,29 @@ def __setattr__(self, attr, val, /, _set=Router.__setattr__):
 setattr(Router, "__setattr__", __setattr__)
 
 
+def get_local_ip() -> str:
+    with socket(AF_INET, SOCK_DGRAM) as sock:
+        #sock.connect(("8.8.8.8", 80))
+        sock.connect(("192.168.1.1", 80))
+        try:
+            return sock.getsockname()[0]
+        except:
+            return ""
+
+
+def is_localhost(host: str, /) -> bool:
+    return host in ("localhost", "127.0.0.1", "0.0.0.0", "::1")
+
+
+def is_private(host: str, /) -> bool:
+    if host == "localhost" or host.endswith(".local"):
+        return True
+    try:
+        return ip_address(host).is_private
+    except ValueError:
+        return False
+
+
 class ChainedList(list[T]):
 
     def __init__(self, iterable: Iterable[T] = (), /, *appendices: Sequence[T]):
@@ -165,6 +191,7 @@ def make_application(
     base_url: str = "http://localhost", 
     custom_proxy: bool | Callable = True, 
     ws_mode: None | Literal["", "r", "w", "rw"] = None, 
+    resolve_localhost: bool = False, 
     debug: bool = False, 
 ) -> ApplicationWithMethods:
     """创建一个 blacksheep 应用，用于反向代理 emby，以修改一些数据响应
@@ -183,6 +210,7 @@ def make_application(
         - 如果为 "r"，则代理为单向 websocket，只进行发送（写）
         - 如果为 "rw"，则代理为双向 websocket，会进行接收（读）和发送（写）
 
+    :param resolve_localhost: 如果 base_url 为 localhost 地址，是否获取其实际局域网地址
     :param debug: 启用调试，会输出 DEBUG 级别日志，也会产生更详细的报错信息
 
     :return: 一个 blacksheep 应用，你可以 2 次扩展，并用 uvicorn 运行
@@ -190,6 +218,15 @@ def make_application(
     if not base_url.startswith(("http://", "https://")):
         raise ValueError(f"not a valid http/https base_url: {base_url!r}")
     base_url = base_url.rstrip("/")
+    base_urlp = urlsplit(base_url)
+    base_url_hostname = base_urlp.hostname or "localhost"
+    base_url_is_localhost = is_localhost(base_url_hostname)
+    base_url_is_private = base_url_is_localhost or is_private(base_url_hostname)
+    if base_url_is_localhost and resolve_localhost:
+        base_url_hostname = get_local_ip()
+        base_url_port = (base_urlp.netloc or "").removeprefix(base_urlp.hostname or "")
+        base_urlp = base_urlp._replace(netloc=base_url_hostname + base_url_port)
+        base_url = urlunsplit(base_urlp)
 
     router = Router()
     app = ApplicationWithMethods(router=router, show_error_details=debug)
@@ -267,8 +304,20 @@ def make_application(
         request: Request, 
         url: None | str = None, 
         timeout: None | int | float = None, 
+        redirect_first: bool = False, 
     ) -> Response:
         if url is None:
+            if redirect_first and request.method.upper() in ("GET", "HEAD"):
+                response = redirect(base_url + str(request.url))
+                remote_hostname = urlsplit("http://" + request.host).hostname or "localhost"
+                if base_url_is_localhost:
+                    if is_private(remote_hostname) if resolve_localhost else is_localhost(remote_hostname):
+                        return response
+                elif base_url_is_private:
+                    if is_private(remote_hostname):
+                        return response
+                else:
+                    return response
             http_resp = await redirect_request(request, timeout=timeout)
             response, _ = await make_response(request, http_resp)
             return response
